
From: Nick Wilson <njw@osdl.org>

This patch makes use of ALIGN() to remove duplicate round-up code.

Signed-off-by: Nick Wilson <njw@osdl.org>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 25-akpm/include/linux/a.out.h |    2 +-
 25-akpm/kernel/resource.c     |    2 +-
 25-akpm/lib/bitmap.c          |    3 +--
 25-akpm/mm/bootmem.c          |    6 +++---
 4 files changed, 6 insertions(+), 7 deletions(-)

diff -puN include/linux/a.out.h~use-align-to-remove-duplicate-code include/linux/a.out.h
--- 25/include/linux/a.out.h~use-align-to-remove-duplicate-code	Fri Apr  8 17:25:24 2005
+++ 25-akpm/include/linux/a.out.h	Fri Apr  8 17:25:24 2005
@@ -138,7 +138,7 @@ enum machine_type {
 #endif
 #endif
 
-#define _N_SEGMENT_ROUND(x) (((x) + SEGMENT_SIZE - 1) & ~(SEGMENT_SIZE - 1))
+#define _N_SEGMENT_ROUND(x) ALIGN(x, SEGMENT_SIZE)
 
 #define _N_TXTENDADDR(x) (N_TXTADDR(x)+(x).a_text)
 
diff -puN kernel/resource.c~use-align-to-remove-duplicate-code kernel/resource.c
--- 25/kernel/resource.c~use-align-to-remove-duplicate-code	Fri Apr  8 17:25:24 2005
+++ 25-akpm/kernel/resource.c	Fri Apr  8 17:25:24 2005
@@ -265,7 +265,7 @@ static int find_resource(struct resource
 			new->start = min;
 		if (new->end > max)
 			new->end = max;
-		new->start = (new->start + align - 1) & ~(align - 1);
+		new->start = ALIGN(new->start, align);
 		if (alignf)
 			alignf(alignf_data, new, size, align);
 		if (new->start < new->end && new->end - new->start + 1 >= size) {
diff -puN lib/bitmap.c~use-align-to-remove-duplicate-code lib/bitmap.c
--- 25/lib/bitmap.c~use-align-to-remove-duplicate-code	Fri Apr  8 17:25:24 2005
+++ 25-akpm/lib/bitmap.c	Fri Apr  8 17:25:24 2005
@@ -289,7 +289,6 @@ EXPORT_SYMBOL(__bitmap_weight);
 
 #define CHUNKSZ				32
 #define nbits_to_hold_value(val)	fls(val)
-#define roundup_power2(val,modulus)	(((val) + (modulus) - 1) & ~((modulus) - 1))
 #define unhex(c)			(isdigit(c) ? (c - '0') : (toupper(c) - 'A' + 10))
 #define BASEDEC 10		/* fancier cpuset lists input in decimal */
 
@@ -316,7 +315,7 @@ int bitmap_scnprintf(char *buf, unsigned
 	if (chunksz == 0)
 		chunksz = CHUNKSZ;
 
-	i = roundup_power2(nmaskbits, CHUNKSZ) - CHUNKSZ;
+	i = ALIGN(nmaskbits, CHUNKSZ) - CHUNKSZ;
 	for (; i >= 0; i -= CHUNKSZ) {
 		chunkmask = ((1ULL << chunksz) - 1);
 		word = i / BITS_PER_LONG;
diff -puN mm/bootmem.c~use-align-to-remove-duplicate-code mm/bootmem.c
--- 25/mm/bootmem.c~use-align-to-remove-duplicate-code	Fri Apr  8 17:25:24 2005
+++ 25-akpm/mm/bootmem.c	Fri Apr  8 17:25:24 2005
@@ -57,7 +57,7 @@ static unsigned long __init init_bootmem
 	pgdat->pgdat_next = pgdat_list;
 	pgdat_list = pgdat;
 
-	mapsize = (mapsize + (sizeof(long) - 1UL)) & ~(sizeof(long) - 1UL);
+	mapsize = ALIGN(mapsize, sizeof(long));
 	bdata->node_bootmem_map = phys_to_virt(mapstart << PAGE_SHIFT);
 	bdata->node_boot_start = (start << PAGE_SHIFT);
 	bdata->node_low_pfn = end;
@@ -178,7 +178,7 @@ __alloc_bootmem_core(struct bootmem_data
 	} else
 		preferred = 0;
 
-	preferred = ((preferred + align - 1) & ~(align - 1)) >> PAGE_SHIFT;
+	preferred = ALIGN(preferred, align) >> PAGE_SHIFT;
 	preferred += offset;
 	areasize = (size+PAGE_SIZE-1)/PAGE_SIZE;
 	incr = align >> PAGE_SHIFT ? : 1;
@@ -219,7 +219,7 @@ found:
 	 */
 	if (align < PAGE_SIZE &&
 	    bdata->last_offset && bdata->last_pos+1 == start) {
-		offset = (bdata->last_offset+align-1) & ~(align-1);
+		offset = ALIGN(bdata->last_offset, align);
 		BUG_ON(offset > PAGE_SIZE);
 		remaining_size = PAGE_SIZE-offset;
 		if (size < remaining_size) {
_
